SystemOrganization addCategory: #ConfigurationOfPunQLite!

Object subclass: #ConfigurationOfPunQLite
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfPunQLite'!

!ConfigurationOfPunQLite class methodsFor: 'development support' stamp: 'MasashiUmezawa 12/17/2013 00:24'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfPunQLite class methodsFor: 'private' stamp: 'MasashiUmezawa 12/22/2013 22:36'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfPunQLite class methodsFor: 'catalog' stamp: 'MasashiUmezawa 12/30/2013 00:11'!
catalogChangeLog
		
 ^ '- Version 1.1
[[[
(ConfigurationOfPunQLite project version: ''1.1'') load
]]]
- Version 1.1.1
[[[
(ConfigurationOfPunQLite project version: ''1.1.1'') load
]]]
'
	
	! !

!ConfigurationOfPunQLite class methodsFor: 'catalog' stamp: 'MasashiUmezawa 12/30/2013 00:16'!
catalogDescription

^ 
'UnQLite binding for Pharo Smalltalk. UnQLite is a fast, lightweight, portable, embedded KVS with a simple scripting engine (Jx9). By using PunQLite, you can store/load lots of data as if just using a normal Dictionary.

PunQLite uses UnQLite shared library. If you have no time to compile, just get pre-built binary from the github project page (https://github.com/mumez/PunQLite).

'! !

!ConfigurationOfPunQLite class methodsFor: 'catalog' stamp: 'DamienCassou 1/5/2014 10:27'!
catalogKeyClassesAndExample

	^ 'It is composed of some keys classes: 
		
- ==PqDatabase== represents a database. You can open a DB and put/get values like a dictionary.
		
- ==PqCursor== is an iterator on a database. You can jump to the specific point by seek:. 

Example:
[[[ 
db := PqDatabase openOnMemory.
db at: ''Smalltalk'' put: ''COOL''.
db at: ''Pharo'' put: ''HOT''.
db at: ''Smalltalk'' ifPresent: [:data |
    data asString inspect
].
Transcript cr; show: db keys.
db do: [:cursor |
    Transcript cr; show: cursor currentStringKey; space; show: cursor currentStringValue.       
].
db close.
]]]
	
Tests of the ==PqDatabase== class are the place to start to learn the API.
You can see more samples on github (https://github.com/mumez/PunQLite). 

'! !

!ConfigurationOfPunQLite class methodsFor: 'catalog' stamp: 'MasashiUmezawa 12/29/2013 23:51'!
catalogKeywords
	^ #(persistence database UnQLite KVS NoSQL NativeBoost)! !

!ConfigurationOfPunQLite class methodsFor: 'private' stamp: 'MasashiUmezawa 12/17/2013 00:24'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfPunQLite class methodsFor: 'private' stamp: 'MasashiUmezawa 12/22/2013 22:37'!
ensureMetacelloBaseConfiguration

  Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfPunQLite class methodsFor: 'metacello tool support' stamp: 'MasashiUmezawa 12/17/2013 00:24'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfPunQLite class methodsFor: 'loading' stamp: 'MasashiUmezawa 12/17/2013 00:24'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfPunQLite class methodsFor: 'loading' stamp: 'MasashiUmezawa 12/17/2013 00:24'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfPunQLite class methodsFor: 'loading' stamp: 'MasashiUmezawa 12/17/2013 00:24'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfPunQLite class methodsFor: 'accessing' stamp: 'MasashiUmezawa 12/17/2013 00:24'!
project

	^self new project! !

!ConfigurationOfPunQLite class methodsFor: 'development support' stamp: 'MasashiUmezawa 12/17/2013 00:24'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfPunQLite methodsFor: 'baselines' stamp: 'MasashiUmezawa 12/17/2013 00:43'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'pharo' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/MasashiUmezawa/PunQLite/main'.
		spec 
			package: 'PunQLite-Core' with: [
				spec requires: #(). ];
			package: 'PunQLite-DB' with: [
				spec requires: #('PunQLite-Core' ). ];
			package: 'PunQLite-Tests'.
		spec 
			group: 'default' with: #('Core' );
			group: 'Core' with: #('PunQLite-Core' 'PunQLite-DB' );
			group: 'Tests' with: #('PunQLite-Tests' ). ].
! !

!ConfigurationOfPunQLite methodsFor: 'baselines' stamp: 'MasashiUmezawa 12/22/2013 22:40'!
baseline11: spec
	<version: '1.1-baseline'>

	spec for: #'pharo' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://smalltalkhub.com/mc/MasashiUmezawa/PunQLite/main'.
		spec 
			package: 'PunQLite-Core' with: [
				spec requires: #(). ];
			package: 'PunQLite-DB' with: [
				spec requires: #('PunQLite-Core' ). ];
			package: 'PunQLite-Jx9' with: [
				spec requires: #('PunQLite-DB' ). ];
			package: 'PunQLite-Tests' with: [
				spec requires: #('PunQLite-Jx9'). ].
		spec 
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('PunQLite-Core' 'PunQLite-DB' 'PunQLite-Jx9' );
			group: 'Tests' with: #('PunQLite-Tests' ). ].
! !

!ConfigurationOfPunQLite methodsFor: 'accessing' stamp: 'MasashiUmezawa 12/17/2013 00:24'!
customProjectAttributes
    "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes "

    ^ #()! !

!ConfigurationOfPunQLite methodsFor: 'symbolic versions' stamp: 'MasashiUmezawa 12/30/2013 00:23'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'pharo' version: '1.1.1'.
! !

!ConfigurationOfPunQLite methodsFor: 'accessing' stamp: 'MasashiUmezawa 12/17/2013 00:24'!
project
    ^ project
        ifNil: [ 
            "Bootstrap Metacello if it is not already loaded"
            self class ensureMetacello.
            project := MetacelloMCProject new projectAttributes: self customProjectAttributes.	"Create the Metacello project"
            (Smalltalk at: #'MetacelloVersionConstructor') on: self project: project.	"Construct the project"
            project loadType: #'linear'.	"change to #atomic if desired"
            project ]! !

!ConfigurationOfPunQLite methodsFor: 'symbolic versions' stamp: 'MasashiUmezawa 12/22/2013 01:58'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'pharo' version: '1.1'.
! !

!ConfigurationOfPunQLite methodsFor: 'versions' stamp: 'MasashiUmezawa 12/17/2013 00:44'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'pharo' do: [
		spec blessing: #'development'.
		spec 
			package: 'PunQLite-Core' with: 'PunQLite-Core-MasashiUmezawa.1';
			package: 'PunQLite-DB' with: 'PunQLite-DB-MasashiUmezawa.1';
			package: 'PunQLite-Tests' with: 'PunQLite-Tests-MasashiUmezawa.1'. ].
! !

!ConfigurationOfPunQLite methodsFor: 'versions' stamp: 'MasashiUmezawa 12/29/2013 23:48'!
version111: spec
	<version: '1.1.1' imports: #('1.1-baseline' )>

	spec for: #'pharo' do: [
		spec blessing: #'development'.
		spec 
			package: 'PunQLite-Core' with: 'PunQLite-Core-MasashiUmezawa.11';
			package: 'PunQLite-DB' with: 'PunQLite-DB-MasashiUmezawa.8';
			package: 'PunQLite-Jx9' with: 'PunQLite-Jx9-MasashiUmezawa.5';
			package: 'PunQLite-Tests' with: 'PunQLite-Tests-MasashiUmezawa.8'. ].
! !

!ConfigurationOfPunQLite methodsFor: 'versions' stamp: 'MasashiUmeawa 12/23/2013 23:38'!
version11: spec
	<version: '1.1' imports: #('1.1-baseline' )>

	spec for: #'pharo' do: [
		spec blessing: #'development'.
		spec 
			package: 'PunQLite-Core' with: 'PunQLite-Core-MasashiUmezawa.11';
			package: 'PunQLite-DB' with: 'PunQLite-DB-MasashiUmezawa.6';
			package: 'PunQLite-Jx9' with: 'PunQLite-Jx9-MasashiUmezawa.5';
			package: 'PunQLite-Tests' with: 'PunQLite-Tests-MasashiUmezawa.7'. ].
! !
